# IEML python implementation

IEML is an artificial natural language created by the french philosopher Pierre Levy [blog](https://pierrelevyblog.com/).
The key idea is to define a unique representation for meaning, that is easily manipulated by an algorithm.
First, a set of atomic basic meaning objects and theirs semantics relationship are defined in a dictionary.
Then we use those terms to build more complex syntactic structures as word, sentence, super-sentence, text and hypertext.

